diff src/redisplay.c @ 5619:75ad4969a16d

Replace the 'flush face property with the opposite 'shrink one. lisp/ChangeLog addition: 2011-12-26 Didier Verna <didier@xemacs.org> * cl-macs.el (face-flush-p): Removed. * cl-macs.el (face-shrink-p): New. * faces.el (face-flush-p): Removed. * faces.el (face-shrink-p): New. * faces.el (set-face-flush-p): Removed. * faces.el (set-face-shrink-p): New. * cus-face.el (custom-face-attributes): * faces.el (set-face-property): * faces.el (face-equal): * x-faces.el (x-init-face-from-resources): * x-faces.el (make-face-x-resource-internal): Replace the 'flush property with the opposite 'shrink one. src/ChangeLog addition: 2011-12-26 Didier Verna <didier@xemacs.org> * lisp.h: * faces.c (mark_face): * faces.c (face_equal): * faces.c (face_getprop): * faces.c (face_putprop): * faces.c (face_remprop): * faces.c (face_plist): * faces.c (reset_face): * faces.c (update_face_inheritance_mapper): * faces.c (Fmake_face): * faces.c (update_face_cachel_data): * faces.c (merge_face_cachel_data): * faces.c (Fcopy_face): * faces.c (syms_of_faces): * faces.c (vars_of_faces): * faces.c (complex_vars_of_faces): * faces.h (struct Lisp_Face): * faces.h (struct face_cachel): * faces.h (WINDOW_FACE_CACHEL_SHRINK_P): * faces.h (FACE_SHRINK_P): * fontcolor.c (face_boolean_validate): Replace the 'flush property with the opposite 'shrink one. * redisplay.c (create_text_block): * redisplay.c (create_string_text_block): Ditto. Invert the logic for storing a new clear_findex in the display lines.
author Didier Verna <didier@xemacs.org>
date Mon, 26 Dec 2011 15:04:25 +0100
parents b0d712bbc2a6
children 81fee4aee9b6
line wrap: on
line diff
--- a/src/redisplay.c	Fri Dec 23 10:34:40 2011 +0000
+++ b/src/redisplay.c	Mon Dec 26 15:04:25 2011 +0100
@@ -2500,10 +2500,10 @@
 	     to the line and end this loop. */
 	  else if (data.ch == '\n')
 	    {
 	      /* Update the clearing face index when the flush property is
 		 set. -- dvl */ 
 	      if ((data.findex > DEFAULT_INDEX)
-		  && WINDOW_FACE_CACHEL_FLUSH_P (w, data.findex))
+		  && ! WINDOW_FACE_CACHEL_SHRINK_P (w, data.findex))
 		dl->clear_findex = data.findex;
 
 	      /* We aren't going to be adding an end glyph so give its
@@ -4938,10 +4938,10 @@
 	     to the line and end this loop. */
 	  else if (data.ch == '\n')
 	    {
 	      /* Update the clearing face index when the flush property is
 		 set. -- dvl */ 
 	      if ((data.findex > DEFAULT_INDEX)
-		  && WINDOW_FACE_CACHEL_FLUSH_P (w, data.findex))
+		  && ! WINDOW_FACE_CACHEL_SHRINK_P (w, data.findex))
 		dl->clear_findex = data.findex;
 
 	      /* We aren't going to be adding an end glyph so give its
@@ -2500,10 +2500,10 @@
 	  else if (data.ch == '\n')
 	    {
-	      /* Update the clearing face index when the flush property is
+	      /* Update the clearing face index unless the shrink property is
 		 set. -- dvl */ 
 	      if ((data.findex > DEFAULT_INDEX)
@@ -4938,10 +4938,10 @@
 	  else if (data.ch == '\n')
 	    {
-	      /* Update the clearing face index when the flush property is
+	      /* Update the clearing face index unless the shrink property is
 		 set. -- dvl */ 
 	      if ((data.findex > DEFAULT_INDEX)